@@ -121,6 +121,9 @@ public:
                 hash = (i<0) ? i-1 : i;
                 setflag(status_flags::evaluated | status_flags::expanded);
         }
+	numeric(unsigned long i) : 
+                basic(&numeric::tinfo_static), t(LONG), v(i), hash(i)
+        { setflag(status_flags::evaluated | status_flags::expanded); }
 	numeric(long numer, long denom);
 	numeric(double d);
 	numeric(mpz_t bigint);
@@ -320,7 +323,6 @@ protected:
 		const char *mul_sym, unsigned level, bool latex) const;
 	void do_print(const print_context & c, unsigned level) const override;
 	void do_print_latex(const print_latex & c, unsigned level) const;
-	void do_print_csrc(const print_csrc & c, unsigned level) const;
 	void do_print_tree(const print_tree & c, unsigned level) const override;
 	void do_print_python_repr(const print_python_repr & c, unsigned level) const override;
 
@@ -371,6 +373,7 @@ const numeric gamma(const numeric &x, PyObject* parent=nullptr);
 const numeric rgamma(const numeric &x, PyObject* parent=nullptr);
 const numeric psi(const numeric &x, PyObject* parent=nullptr);
 const numeric psi(const numeric &n, const numeric &x);
+const numeric beta(const numeric &x, const numeric &y, PyObject* parent=nullptr);
 const numeric factorial(const numeric &n);
 const numeric doublefactorial(const numeric &n);
 const numeric binomial(unsigned long n, unsigned long k);
